@@ -604,7 +604,7 @@ class HttpLambdaAuthorizer(
                 *,
                 authorizer_name: typing.Optional[builtins.str] = None,
                 identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
+                response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
                 results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
             ) -> None:
                 ...
@@ -696,7 +696,7 @@ class HttpLambdaAuthorizerProps:
                 *,
                 authorizer_name: typing.Optional[builtins.str] = None,
                 identity_source: typing.Optional[typing.Sequence[builtins.str]] = None,
-                response_types: typing.Optional[typing.Sequence["HttpLambdaResponseType"]] = None,
+                response_types: typing.Optional[typing.Sequence[HttpLambdaResponseType]] = None,
                 results_cache_ttl: typing.Optional[aws_cdk.core.Duration] = None,
             ) -> None:
                 ...
